@@ -400,7 +400,7 @@ bool FtpDirectoryParser::parseMlsd(const TQString &line, DirectoryEntry &entry)
   return true;
 }
 
-bool FtpDirectoryParser::parseUnixPermissions(const TQString &permissions, DirectoryEntry &entry)
+void FtpDirectoryParser::parseUnixPermissions(const TQString &permissions, DirectoryEntry &entry)
 {
   int p = 0;
   
